*This code prepares the variables in the ASCII dataset for use in the Stata program that produces the analysis reported in the paper "Monetary Policy and Financial Stability: Cross-Country Evidence" (Christian Friedrich, Kristina Hess, and Rose Cunningham), Journal of Money, Credit, and Banking 
*Note: the file path must be defined in line 9 below*

********************************************************************************
********************************** Set up **************************************
********************************************************************************

clear all
global resultspath "ADD PATH HERE"

import delim using "${resultspath}\MPFSdata_csv"

*panel data format
format datevar %tq
	drop dq
	rename datevar dq
	xtset ifs dq
format yearvar %td
	drop year
	rename yearvar year


********************************************************************************
**** Convert lower-case variable names to the cases used in the program file ***
********************************************************************************

rename   policy Policy
rename   cpi CPI
rename   cpiyoy CPIyoy
rename   natinf NatInf
rename   inftarget InfTarget
rename   rgdp rGDP
rename   rgdpyoy rGDPyoy
rename   neer NEER
rename   reer REER
rename   inf1yr Inf1yr
rename   fsr FSR
rename   finreg FinReg
rename   rhouse rHouse
rename   credit Credit
rename   credit_hp1 Credit_HP1
rename   credit_hp1_sm8 Credit_HP1_sm8
rename   credit_s8t8 Credit_s8t8
rename   infgap InfGap
rename   cpiyoygap CPIyoyGap
rename   expgap ExpGap
rename   nor NOR
rename   rgdp_c rGDP_c
rename   rgdp_t rGDP_t
rename   rgdpgap rGDPGap
rename   oecdgapq4 OECDGapQ4
rename   qoecdgap qOECDGap
rename   zlb ZLB
rename   reerqoq REERqoq
rename   neerqoq NEERqoq
rename   fsbase FSbase
rename   itbase ITbase
rename   opbase OPbase
rename   discb DiscB
rename   discnc DiscNC
rename   fso2 FSO2
rename   fso3 FSO3
rename   fso7 FSO7
rename   dim1 Dim1
rename   l1fso3 L1FSO3
rename   l1rgdpgap L1rGDPGap
rename   rgdpgap_fso2 rGDPGap_FSO2
rename   rgdpgap_fso3 rGDPGap_FSO3
rename   l1rgdpgap_fso3 L1rGDPGap_FSO3
rename   rgdpgap_fso7 rGDPGap_FSO7
rename   rgdpgap_l1fso3 rGDPGap_L1FSO3
rename   qoecdgap_fso3 qOECDGap_FSO3
rename   infgap_fso3 InfGap_FSO3
rename   cpiyoygap_fso3 CPIyoyGap_FSO3
rename   frgdpgap FrGDPGap
rename   frgdpgap_fso3 FrGDPGap_FSO3
rename   inf1yrea Inf1yrEA
rename   expgapea ExpGapEA
rename   l1expgapea L1ExpGapEA
rename   policyk PolicyK
rename   policywx PolicyWX
rename   d4l_rhouse d4l_rHouse
rename   d4l_rcredit d4l_rcredit
rename   fs_st FS_ST
rename   fs_growth FS_Growth
rename   l1fs_dummy L1FS_Dummy
rename   fs_growth_25c FS_Growth_25c
rename   fs_growth_75c FS_Growth_75c
rename   l1fs_growth_25c L1FS_Growth_25c
rename   fs_growth_fso3 FS_Growth_FSO3
rename   fs_growth_25c_fso3 FS_Growth_25c_FSO3
rename   fs_growth_25c_dim1 FS_Growth_25c_Dim1
rename   fs_growth_25c_finreg FS_Growth_25c_FinReg
rename   fs_growth_25c_discb FS_Growth_25c_DiscB
rename   fs_growth_25c_fso7 FS_Growth_25c_FSO7
rename   fs_growth_25c_fso2 FS_Growth_25c_FSO2
rename   fs_growth_25c_l1fso3 FS_Growth_25c_L1FSO3
rename   l1fs_growth_25c_fso3 L1FS_Growth_25c_FSO3
rename   fs_growth_75c_fso3 FS_Growth_75c_FSO3
rename   l1fs_dummy_fso3 L1FS_Dummy_FSO3
rename   l1fs_dummy_dim1 L1FS_Dummy_Dim1
rename   l1fs_dummy_finreg L1FS_Dummy_FinReg
rename   l1fs_dummy_discb L1FS_Dummy_DiscB
rename   fs_st_fso3 FS_ST_FSO3
rename   fs_st_dim1 FS_ST_Dim1
rename   fs_st_finreg FS_ST_FinReg
rename   fs_st_discb FS_ST_DiscB
rename   expgapea_fso3 ExpGapEA_FSO3
rename   expgapea_fso7 ExpGapEA_FSO7
rename   expgapea_fso2 ExpGapEA_FSO2
rename   expgapea_l1fso3 ExpGapEA_L1FSO3
rename   fso_index FSO_Index
rename   l1dlloansr L1dlloansr
rename   l2dlloansr L2dlloansr
rename   l3dlloansr L3dlloansr
rename   l4dlloansr L4dlloansr
rename   l5dlloansr L5dlloansr
rename   l6dlloansr L6dlloansr
rename   l7dlloansr L7dlloansr
rename   l8dlloansr L8dlloansr
rename   l9dlloansr L9dlloansr
rename   l10dlloansr L10dlloansr
rename   l11dlloansr L11dlloansr
rename   l12dlloansr L12dlloansr
rename   l13dlloansr L13dlloansr
rename   l14dlloansr L14dlloansr
rename   l15dlloansr L15dlloansr
rename   l16dlloansr L16dlloansr
rename   l17dlloansr L17dlloansr
rename   l18dlloansr L18dlloansr
rename   l19dlloansr L19dlloansr
rename   l20dlloansr L20dlloansr
rename   fs_growth_25c_l1d4fso3_wt FS_Growth_25c_L1d4FSO3_wt
rename   rgdpgap_l1d4fso3_wt rGDPGap_L1d4FSO3_wt
rename   expgapea_l1d4fso3_wt ExpGapEA_L1d4FSO3_wt
rename   f1fs_growth_25c F1FS_Growth_25c
rename   f1fs_growth_25c_fso3 F1FS_Growth_25c_FSO3
rename   l1expgapea_fso3 L1ExpGapEA_FSO3
rename   rgdp_yy rGDP_yy
rename   l1d4fso3_wt L1d4FSO3_wt


********************************************************************************
****************************** Add variable labels *****************************
********************************************************************************

label variable ifs "country code"
label variable country "country name"
label variable year "year"
label variable Policy "Policy Rate (pp)"
label variable CPI "CPI level"
label variable CPIyoy "CPI Inflation"
label variable NatInf "National inflation measure (%yoy)"
label variable InfTarget "Inflation Target (pp)"
label variable rGDP "Real GDP (level, national currency)"
label variable rGDPyoy "Real GDP growth (%yoy)"
label variable NEER "Nominal effective exchange rate (level)"
label variable REER "Real effective exchange rate (level)"
label variable dq "date, quarterly"
label variable Inf1yr "Inflation, 1-yr Exp."
label variable FSR "Financial stability report (0/1 indicator)"
label variable mandate "Central bank has FS mandate (0/1 indicator)"
label variable FinReg "Regulatory Dimension (see Appendix for details on construction)"
label variable rHouse "House prices (real)"
label variable Credit "Credit to Nonfin Private Sector (%GDP)"
label variable Credit_HP1 "Credit/GDP, Cyclical component of 1-sided HP filter"
label variable Credit_HP1_sm8 "Credit/GDP, Cyclical component of 1-sided HP filter, smoothed over 8 lags"
label variable Credit_s8t8 "Contemporaneous binary credit boom indicator"
label variable ifs111 "Country indicator (1 US; 0 otherwise)"
label variable ifs163 "Country indicator (1 Euro Area; 0 otherwise)"
label variable ifs158 "Country indicator (1 Japan; 0 otherwise)"
label variable ifs112 "Country indicator (1 UK; 0 otherwise)"
label variable ifs156 "Country indicator (1 Canada; 0 otherwise)"
label variable ifs193 "Country indicator (1 Australia; 0 otherwise)"
label variable ifs146 "Country indicator (1 Switzerland; 0 otherwise)"
label variable ifs144 "Country indicator (1 Sweden; 0 otherwise)"
label variable ifs142 "Country indicator (1 Norway; 0 otherwise)"
label variable ifs196 "Country indicator (1 New Zealand; 0 otherwise)"
label variable tfe1 "dq== 160.0000"
label variable tfe2 "dq== 161.0000"
label variable tfe3 "dq== 162.0000"
label variable tfe4 "dq== 163.0000"
label variable tfe5 "dq== 164.0000"
label variable tfe6 "dq== 165.0000"
label variable tfe7 "dq== 166.0000"
label variable tfe8 "dq== 167.0000"
label variable tfe9 "dq== 168.0000"
label variable tfe10 "dq== 169.0000"
label variable tfe11 "dq== 170.0000"
label variable tfe12 "dq== 171.0000"
label variable tfe13 "dq== 172.0000"
label variable tfe14 "dq== 173.0000"
label variable tfe15 "dq== 174.0000"
label variable tfe16 "dq== 175.0000"
label variable tfe17 "dq== 176.0000"
label variable tfe18 "dq== 177.0000"
label variable tfe19 "dq== 178.0000"
label variable tfe20 "dq== 179.0000"
label variable tfe21 "dq== 180.0000"
label variable tfe22 "dq== 181.0000"
label variable tfe23 "dq== 182.0000"
label variable tfe24 "dq== 183.0000"
label variable tfe25 "dq== 184.0000"
label variable tfe26 "dq== 185.0000"
label variable tfe27 "dq== 186.0000"
label variable tfe28 "dq== 187.0000"
label variable tfe29 "dq== 188.0000"
label variable tfe30 "dq== 189.0000"
label variable tfe31 "dq== 190.0000"
label variable tfe32 "dq== 191.0000"
label variable tfe33 "dq== 192.0000"
label variable tfe34 "dq== 193.0000"
label variable tfe35 "dq== 194.0000"
label variable tfe36 "dq== 195.0000"
label variable tfe37 "dq== 196.0000"
label variable tfe38 "dq== 197.0000"
label variable tfe39 "dq== 198.0000"
label variable tfe40 "dq== 199.0000"
label variable tfe41 "dq== 200.0000"
label variable tfe42 "dq== 201.0000"
label variable tfe43 "dq== 202.0000"
label variable tfe44 "dq== 203.0000"
label variable tfe45 "dq== 204.0000"
label variable tfe46 "dq== 205.0000"
label variable tfe47 "dq== 206.0000"
label variable tfe48 "dq== 207.0000"
label variable tfe49 "dq== 208.0000"
label variable tfe50 "dq== 209.0000"
label variable tfe51 "dq== 210.0000"
label variable tfe52 "dq== 211.0000"
label variable tfe53 "dq== 212.0000"
label variable tfe54 "dq== 213.0000"
label variable tfe55 "dq== 214.0000"
label variable tfe56 "dq== 215.0000"
label variable tfe57 "dq== 216.0000"
label variable tfe58 "dq== 217.0000"
label variable tfe59 "dq== 218.0000"
label variable tfe60 "dq== 219.0000"
label variable InfGap "National inflation (%yoy) less Inflation Target"
label variable CPIyoyGap "CPI inflation (%yoy) less Inflation Target"
label variable ExpGap "Infl. Exp. Gap"
label variable NOR "Indicator (1 if Norway from 2000q1 to 2003q1; 0 otherwise"
label variable rGDP_c "rGDP cyclical component from hp filter"
label variable rGDP_t "rGDP trend component from hp filter"
label variable rGDPGap "Output Gap"
label variable quarter "quarter indicator"
label variable OECDGapQ4 "Output Gap, annual OECD measure"
label variable qOECDGap "OECD Output Gap"
label variable ZLB "Indicator (1 at the zero lower bound; 0 otherwise)"
label variable REERqoq "REER (% change, quarter-over-quarter)"
label variable NEERqoq "NEER (% change, quarter-over-quarter)"
label variable FSbase "Financial stability terms (raw wordcount)"
label variable ITbase "Inflation terms (raw wordcount)"
label variable OPbase "Output terms (raw wordcount)"
label variable DiscB "Discretionary Dimension (see Appendix for details on construction)"
label variable DiscNC "Alt. Discretionary Dimension (ex. credit)"
label variable FSO2 "Alternative FSO Index: 4 dimensions (see Appendix for more detail)"
label variable FSO3 "FSO Index (see Appendix for details on construction)"
label variable FSO7 "Alternative FSO Index: Alt 3rd dimension (see Appendix for more detail)"
label variable Dim1 "Statutory Dimension (see Appendix for details on construction)"
label variable L1FSO3 "FSO Index (t-1)"
label variable L1rGDPGap "Output gap at t-1"
label variable rGDPGap_FSO2 "Output Gap x 4-dim FSO Index"
label variable rGDPGap_FSO3 "Output Gap x FSO Index"
label variable L1rGDPGap_FSO3 "Output Gap (t-1) x FSO Index"
label variable rGDPGap_FSO7 "Output Gap x Alt 3rd-dim FSO Index"
label variable rGDPGap_L1FSO3 "Output Gap x FSO Index (t-1)"
label variable qOECDGap_FSO3 "Alt Output Gap (OECD measure) x FSO Index"
label variable InfGap_FSO3 "National inflation less target x FSO Index"
label variable CPIyoyGap_FSO3 "CPI inflation less target x FSO Index"
label variable FrGDPGap "Output gap at t+1"
label variable FrGDPGap_FSO3 "Output Gap (t+1) x FSO Index"
label variable dlloansr "log difference, real credit"
label variable gdpcrisis "1 if negative real GDP growth, 0 otherwise"
label variable comcrisis2y "Alt. FS crisis indicator (see Economic Implications section for more detail)"
label variable Inf1yrEA "Inflation expectations (pp)"
label variable ExpGapEA "Inf. Exp. Gap"
label variable L1ExpGapEA "Inf Exp Gap at t-1"
label variable PolicyK "Policy Rate (including Krippner shadow rate estimates"
label variable PolicyWX "Policy Rate (including Wu Xia shadow rate estimates)"
label variable rcredit "real credit"
label variable d4l_rHouse "year-over-year log difference of real house prices"
label variable d4l_rcredit "year-over-year log difference of real credit"
label variable cri_gc0orh0_a4_bf "FS crisis indicator (see Methodology section for more detail)"
label variable FS_ST "Crisis Probability Measure (see Appendix for details on construction)"
label variable FS_Growth "Growth-Based FS Measure (see Appendix for details on construction)"
label variable L1FS_Dummy "Binary Credit Boom Indicator (t-1) (see Appendix for details on construction)"
label variable FS_Growth_25c "Growth-Based FS Measure, ex Strong Fin downturns (more detail in Appendix)"
label variable FS_Growth_75c "Growth-Based FS Measure, Fin booms only (more detail in Appendix)"
label variable L1FS_Growth_25c "Growth-Based FS Measure, ex Strong Fin downturns (t-1)"
label variable FS_Growth_FSO3 "Growth-Based FS Measure x FSO Index"
label variable FS_Growth_25c_FSO3 "Growth-Based FS Measure (ex Strong Fin downturns) x FSO Index"
label variable FS_Growth_25c_Dim1 "Growth-Based FS Measure (ex Strong Fin downturns) x Statutory Dimension"
label variable FS_Growth_25c_FinReg "Growth-Based FS Measure (ex Strong Fin downturns) x Regulatory Dimension"
label variable FS_Growth_25c_DiscB "Growth-Based FS Measure (ex Strong Fin downturns) x Discretionary Dimension"
label variable FS_Growth_25c_FSO7 "Growth-Based FS Measure (ex Strong Fin downturns) x Alt 3rd-dim FSO Index"
label variable FS_Growth_25c_FSO2 "Growth-Based FS Measure (ex Strong Fin downturns) x 4-dim FSO Index"
label variable FS_Growth_25c_L1FSO3 "FS Growth Measure (ex Strong Fin Downturns) x FSO Index (t-1)"
label variable L1FS_Growth_25c_FSO3 "Growth-Based FS Measure (ex Strong Fin downturns) (t-1) x FSO Index"
label variable FS_Growth_75c_FSO3 "Growth-Based FS Measure (Fin booms only) x FSO Index"
label variable L1FS_Dummy_FSO3 "Binary Credit Boom Indicator (t-1) x FSO3"
label variable L1FS_Dummy_Dim1 "Binary Credit Boom Indicator (t-1) x Statutory Dimension"
label variable L1FS_Dummy_FinReg "Binary Credit Boom Indicator (t-1) x Regulatory Dimension"
label variable L1FS_Dummy_DiscB "Binary Credit Boom Indicator (t-1) x Discretionary Dimension"
label variable FS_ST_FSO3 "Crisis Probability Measure x FSO Index"
label variable FS_ST_Dim1 "Crisis Probability Measure x Statutory Dimension"
label variable FS_ST_FinReg "Crisis Probability Measure x Regulatory Dimension"
label variable FS_ST_DiscB "Crisis Probability Measure x Discretionary Dimension"
label variable ExpGapEA_FSO3 "Inf. Exp. Gap x FSO Index"
label variable ExpGapEA_FSO7 "Inf Exp Gap x Alt 3rd-dim FSO Index"
label variable ExpGapEA_FSO2 "Inf Exp Gap x 4-dim FSO Index"
label variable ExpGapEA_L1FSO3 "Inflation Gap x FSO Index (t-1)"
label variable FSO_Index "		"
label variable realrategap "Real rate gap (Real Policy Interest Rate less Natural Interest Rate)"
label variable infl "CPI inflation (for scatter plots)"
label variable rGDP_yy "real GDP growth (for scatter plots)"
label variable infl_gap "absolution CPI inflation gap (for scatter plots)"
label variable dpolicy "Policy Interest Rate, q/q change (ppt)"
label variable L1dlloansr "		"
label variable L2dlloansr "		"
label variable L3dlloansr "		"
label variable L4dlloansr "		"
label variable L5dlloansr "		"
label variable L6dlloansr "		"
label variable L7dlloansr "		"
label variable L8dlloansr "		"
label variable L9dlloansr "		"
label variable L10dlloansr "		"
label variable L11dlloansr "		"
label variable L12dlloansr "		"
label variable L13dlloansr "		"
label variable L14dlloansr "		"
label variable L15dlloansr "		"
label variable L16dlloansr "		"
label variable L17dlloansr "		"
label variable L18dlloansr "		"
label variable L19dlloansr "		"
label variable L20dlloansr "		"
label variable L1d4FSO3_wt "Year-over-year change in FSO Index (t-1), ex top and bottom 1%"
label variable FS_Growth_25c_L1d4FSO3_wt "FS Growth Measure (ex Strong Fin Downturns) x yoy change in the FSO Index (t-1)"
label variable rGDPGap_L1d4FSO3_wt "Output Gap x yoy change in the FSO Index (t-1)"
label variable ExpGapEA_L1d4FSO3_wt "Inflation Gap x yoy change in the FSO Index (t-1)"
label variable F1FS_Growth_25c "FS Growth Measure (ex Strong Fin Downturns) (t+1)"
label variable F1FS_Growth_25c_FSO3 "FS Growth Measure (ex Strong Fin Downturns) (t+1) x FSO Index"
label variable L1ExpGapEA_FSO3 "Inflation Gap (t-1) x FSO Index	"
label variable ge "government effectiveness"
label variable fb_nshare2 "number share of foreign banks"

	
********************************************************************************
******************************** Save the data set *****************************
********************************************************************************
save "${resultspath}\MPFSdata_stata", replace	


********************************************************************************
********************************* END OF DO FILE *******************************
********************************************************************************
